function [matrix, dimension] = get_matrix_from_csv_file(filename)
    % [matrix, dimension] = get_matrix_from_csv_file(filename)
    % 
    %  input:
    %           filename  = Name of csv-file to read in
    % output:
    %           matrix    = Connectivity matrix read from file
    %           dimension = Number of nodes in read in network
    %
    % Function reads in the given csv-file and checks that the read-in matrix
    % is quadratic. If not, an error is raised. 
    
    % Christoph Feenders (ne Echtermeyer), 2009-2011

    matrix = csvread(filename);
    [rows, columns] = size(matrix);
    if( rows ~= columns )
        error( 'matrix not quadratic' );
    end
    dimension   = columns; 
    
    zero_colums = find(sum(matrix,1)==0);
    zero_rows   = find(sum(matrix,2)==0)'; 

    % following works for undirected networks only
    if size(intersect(zero_colums, zero_rows), 2) > 0
        disp('WARNING: network has isolated nodes')
    end
end
