function save_plot(handles)
    % save_plot(handles)
    % 
    %  input:
    %           handles = Handle structure of BtA-GUI
    % output:
    %           (none)
    %
    % Function saves plots shown in GUI to PDF file.
    
    % Christoph Echtermeyer, 2009 
    
    if(isfield(handles, 'fig1') > 0)
        % function called by command line workflow
    
        image_basename = sprintf('%s_bw_%.2f_w_%i_k_%i', ...
            handles.file_basename, handles.bandwidth, handles.w, handles.k);
        
        fn1 = save_and_crop(image_basename, '1', handles.fig1);
        fn2 = save_and_crop(image_basename, '2', handles.fig2);
        fn3 = save_and_crop(image_basename, '3', handles.fig3);
        fn4 = save_and_crop(image_basename, '4', handles.fig4);
        fn5 = save_and_crop(image_basename, '5', handles.fig5);
        fn_joined = sprintf('%s.pdf', image_basename);
        cmd = sprintf('gs -dBATCH -dNOPAUSE -q -sDEVICE=pdfwrite -sOutputFile="%s" "%s" "%s" "%s" "%s" "%s" && rm "%s" "%s" "%s" "%s" "%s"', ...
            fn_joined, fn1, fn2, fn3, fn4, fn5, fn1, fn2, fn3, fn4, fn5);
        system(cmd);
    
    else % called from Matlab-GUI
    
        image_filename = sprintf('%s_bw_%.2f_w_%i_k_%i.pdf', ...
            handles.file_basename, handles.bandwidth, handles.w, handles.k);

        axes_to_save = [handles.axes1, handles.axes2, handles.axes3, handles.axes4, handles.axes5];
        no_of_axes_to_save = length(axes_to_save);
        
        %create a new figure
        newFig = figure('Visible','off');
        set(newFig,'PaperUnits','centimeters');
        set(gcf, 'PaperSize', [30 20]);
    %    set(newFig,'PaperPositionMode','auto');
        set(gcf, 'PaperPositionMode', 'manual');
        set(gcf, 'PaperPosition', [0 0 30 20]);
        
        j = 1;
        for i = 1:no_of_axes_to_save
            if( i > 2 )
                j = i + 1;
            else
                j = i;
            end
            h = subplot(2,3,j); 
            a = get(axes_to_save(i), 'Children');
            copyobj(a, h); 
            axis('tight');
        end

        %saves the plot
        print(newFig, '-dpdf', image_filename);
        %closes the figure
        close(newFig)
    end
end


function fn = save_and_crop(fn_base, fig_string, fig_handle)
    fn = sprintf('%s.%s.pdf', fn_base, fig_string);
    print(fig_handle, '-dpdf', fn);
    cmd = sprintf('pdfcrop --margins 10 "%s" "%s"', fn, fn);
% comment out line below if pdfcrop installed on your system
%    system(cmd);
end
