function CV_of_degree_cvi = get_coefficient_of_variation_of_neighbour_degrees_cvi(connectivity_matrix) 
    % CV_of_degree_cvi = get_coefficient_of_variation_of_neighbour_degrees_cvi(connectivity_matrix)
    % 
    %  input:
    %           connectivity_matrix = Adjacency matrix
    % output:
    %           CV_of_degree_cvi    = CV of neighbour degrees
    %
    % Function calculates coefficient of variation of each node's neighbour
    % degrees.
    
    % Christoph Feenders (ne Echtermeyer), 2009-2011
    
    no_nodes            = length(connectivity_matrix);
    CV_of_degree_cvi    = NaN(1, no_nodes);
    [~, ~, all_degrees] = get_degrees(connectivity_matrix);
    
    % for each node...
    for i = 1:no_nodes
    
        % find neighbours
        % assume network is undirected; otherwise neighbours are those that can
        % be reached via an outbound connection
        neighbours = find( connectivity_matrix(i,:) == 1 );

        if( ~isempty(neighbours) )
            
            neighbour_degrees = all_degrees(neighbours);  
            mean_val          = mean(neighbour_degrees);
            if( mean_val > 0)
                
                % std (x, opt)
                % std (x) = sqrt (sumsq (x - mean (x)) / (n - 1))
                % If x is a matrix, compute the standard deviation for each column and return them in a row vector.
                % The argument opt determines the type of normalization to use. Valid values are
                % 0: normalizes with N-1, provides the square root of best unbiased estimator of the variance
                % 1: normalizes with N, this provides the square root of the second moment around the mean 
                SD = std(neighbour_degrees, 1);
                CV = SD / mean_val;
            
            else
            
                CV = 0;
            
            end
            
        else
        
            CV = 0;
            
        end
        
        CV_of_degree_cvi(i) = CV;
        
    end
end
