function locality_indices_loci = get_locality_indices_loci(connectivity_matrix)
    % locality_indices_loci = get_locality_indices_loci(connectivity_matrix)
    % 
    %  input:
    %           connectivity_matrix = Adjacency matrix
    % output:
    %           locality_indices_loci
    %                               = List of locality indeces for all nodes
    %
    % Function calculates locality indices for all nodes.
    
    % Christoph Feenders (ne Echtermeyer), 2010-2011
    
    M                     = get_matching_index_mij( connectivity_matrix );
    no_nodes              = length(connectivity_matrix);
    locality_indices_loci = NaN(1,no_nodes);
 
    for i = 1:no_nodes
    
        % determine neighbouring nodes of node i
        % assume network is undirected; otherwise neighbours are those that can
        % be reached via an outbound connection
        neighbours = find( connectivity_matrix(i,:) == 1 );
     
        % if enough neighbours exist average over matching indices of all pairs
        no_of_neighbours = length(neighbours);
        if( no_of_neighbours >= 2)
        
            sum_of_matching_indices = 0.5 * sum(sum(M(neighbours, neighbours)));
            no_of_summations        = 0.5 * no_of_neighbours * (no_of_neighbours - 1);
            locality_index          = sum_of_matching_indices / no_of_summations;
        
        else
        
            locality_index = 1;
        
        end
        
        locality_indices_loci(i) = locality_index;
        
    end
    
end
