function M = get_matching_index_mij(connectivity_matrix)
    % M = get_matching_index_mij(connectivity_matrix)
    % 
    %  input:
    %           connectivity_matrix = Adjacency matrix
    % output:
    %           M                   = Matrix of matching indeces for all nodes
    %
    % Function calculates matching indices for all pairs of nodes.
    
    % Christoph Echtermeyer, 2009-2010
    
    no_of_nodes = length(connectivity_matrix);
    M           = zeros(no_of_nodes);
    
    for i = 1:no_of_nodes
        
        target_source_of_i = find(connectivity_matrix(i,:));
        
        for j = 1:no_of_nodes
        
            target_source_of_j = find(connectivity_matrix(j,:));
            no_of_target_nodes = size(union(target_source_of_i, target_source_of_j), 2);
            
            if( no_of_target_nodes > 0 )

                no_of_common_target_nodes = size(intersect(target_source_of_i, target_source_of_j), 2);
                m_ij = no_of_common_target_nodes / no_of_target_nodes;

            else
            
                m_ij = 0;

            end

            M(i,j) = m_ij;
       
        end
    end
end
