function normalised_average_degrees_ri = get_normalised_average_degrees_ri(connectivity_matrix) 
    % normalised_average_degrees_ri = get_normalised_average_degrees_ri(connectivity_matrix)
    % 
    %  input:
    %           connectivity_matrix = Adjacency matrix
    % output:
    %           normalised_average_degrees_ri
    %                             = List of normalised average degrees
    %
    % Function calculates normalised average degrees and returns them as a list.
    
    % Christoph Feenders (ne Echtermeyer), 2010-2011
            
    no_nodes          = length(connectivity_matrix);
    total_no_of_links = sum(sum(connectivity_matrix));
    
    if( total_no_of_links > 0 )

        [~, ~, all_degrees]          = get_degrees(connectivity_matrix);
        avg_sum_of_neighbour_degrees = NaN(1, no_nodes);

        for i = 1:no_nodes
            
            % determine neighbouring nodes of node i
            % assume network is undirected; otherwise neighbours are those that can
            % be reached via an outbound connection
            neighbours       = find( connectivity_matrix(i,:) == 1 );
            no_of_neighbours = length(neighbours);
            
            if( no_of_neighbours > 0)
                sum_of_neighbour_degrees = sum(all_degrees(neighbours));
                avg_sum_of_neighbour_degrees(i) = sum_of_neighbour_degrees / no_of_neighbours;
            else
                avg_sum_of_neighbour_degrees(i) = 0;
            end
        end
                
        normalised_average_degrees_ri = avg_sum_of_neighbour_degrees / total_no_of_links;
        
    else
    
        normalised_average_degrees_ri = zeros(1, no_nodes);
    
    end
    
end
