function normalised_node_degrees_Ki = get_normalised_node_degrees_Ki(connectivity_matrix) 
    % normalised_node_degrees_Ki = get_normalised_node_degrees_Ki(connectivity_matrix)
    % 
    %  input:
    %           connectivity_matrix = Adjacency matrix
    % output:
    %           normalised_node_degrees_Ki
    %                             = List of normalised node degrees
    %
    % Function calculates normalised node degrees and returns them as a list.
    
    % Christoph Feenders (ne Echtermeyer), 2009-2011
    
    total_no_links = sum(sum(connectivity_matrix));
    
    if( total_no_links > 0 )
    
        [~, ~, all_degrees]        = get_degrees(connectivity_matrix);
        normalised_node_degrees_Ki = 0.5 * all_degrees / total_no_links;

    else
    
        no_of_nodes                = length(connectivity_matrix);
        normalised_node_degrees_Ki = zeros(1, no_of_nodes);
    
    end
    
end
