function [statistics, stats_description] = S1_calculate_stats(connectivity_matrix, handles) 
%function [statistics, stats_description] = S1_calculate_stats(connectivity_matrix) 
    % [statistics, stats_description] = S1_calculate_stats(connectivity_matrix)
    % 
    %  input:
    %           connectivity_matrix = Adjacency matrix
    % output:
    %           statistics          = Matrix of node statistics
    %           stats_description   = Matrix column headers
    %
    % "Beyond the Average"-workflow -- Step 1
    % Calculation of local measures for all network nodes.
    
    % Christoph Feenders (ne Echtermeyer), 2010-2013
        
    % safety check
    [no_of_isolated_nodes, ~] = get_no_isolated_nodes(connectivity_matrix);
    if no_of_isolated_nodes
        error(sprintf('Network %s contains %i isolated nodes.', handles.file_basename, no_of_isolated_nodes))
    end
   
    % get local statistics
    normalised_node_degrees_Ki    = get_normalised_node_degrees_Ki( connectivity_matrix );
    normalised_average_degrees_ri = get_normalised_average_degrees_ri( connectivity_matrix );
    CV_of_degree_cvi              = get_coefficient_of_variation_of_neighbour_degrees_cvi( connectivity_matrix );
    locality_indices_loci         = get_locality_indices_loci( connectivity_matrix );
    cc1                           = get_hierarchical_cluster_coefficient_ccd(connectivity_matrix, 1);
    cc2                           = get_hierarchical_cluster_coefficient_ccd(connectivity_matrix, 2);

    statistics = [      normalised_node_degrees_Ki; ...
                        normalised_average_degrees_ri; ...
                        CV_of_degree_cvi; ...
                        locality_indices_loci; ...
                        cc1; ...
                        cc2 ];
    stats_description = { 'K'; 'r'; 'cv'; 'loc'; 'cc'; 'cc2' };

    
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    no_of_measures_to_apply = 6;
    %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
    
    
    if no_of_measures_to_apply >= 9
        avg_con_len = get_avg_connection_length(connectivity_matrix, handles);
        max_con_len = get_max_connection_length(connectivity_matrix, handles);
        avg_ind_reach = get_avg_indirect_reach(connectivity_matrix, handles);
        statistics = [      statistics; ...
                            avg_con_len; max_con_len; avg_ind_reach; ];
        stats_description{7} = 'acl';
        stats_description{8} = 'mcl';
        stats_description{9} = 'air';
    end
    if no_of_measures_to_apply >= 10
        total_coord_deg = get_total_coordiantion_degree(connectivity_matrix, handles);
        statistics = [      statistics; ...
                            total_coord_deg ];
        stats_description{10} = 'tcd';
    end
    
    statistics = statistics.';
    
end
