function [eigenspace_projection, explained_variance] = S2_PCA(data_for_PCA, target_dimension) 
    % eigenspace_projection = S2_PCA(data_for_PCA, target_dimension)
    % 
    %  input:
    %           data_for_PCA          = Data-matrix to perfrom PCA ones
    %           target_dimension      = Number of PCA components to return
    % output:
    %           eigenspace_projection = Data transformed according to PCs
    %
    % "Beyond the Average"-workflow -- Step 2
    % Project network statistics to PCA-plane.
    
    % Christoph Feenders (ne Echtermeyer), 2009-2013

% This code makes use of the MATLAB Statistics Toolbox. It has been
% by the equivalent computations below, which do not require any toolbox.
% 
%     % before PCA, shift and normalise data (zscore = (data-mean)/stdev)
%     [~, scores, variances] = princomp(zscore(data_for_PCA));
%     eigenspace_projection  = scores(:,1:target_dimension);
%    
%     % calculate amount of variance accounted for by target_dimension-many PCs
%     explained_variance = sum(variances(1:target_dimension)) ./ sum(variances);
   
    no_lines           = size(data_for_PCA, 1);
    % before PCA, shift and normalise data (zscore = (data-mean)/stdev)
    normalised_data    = (data_for_PCA ...
                             - repmat(mean(data_for_PCA), no_lines, 1)) ...
                                 ./ repmat(std(data_for_PCA), no_lines, 1);
    % calculate covariance matrix
    cov_mtx = cov(normalised_data);
    
    % Eigenvector-calculation
    [pc, eigval_mtx]   = eig(cov_mtx); % eigenvectors (pc) and eigvalues
    eigvals            = diag(eigval_mtx);

    % sort components (largest eigenvalue first)
    [eigvals, idx]     = sort(eigvals, 'descend');  
    explained_variance = sum(eigvals(1:target_dimension)) ./ sum(eigvals);
    pc                 = pc(:, idx);

    % data transformation
    eigenspace_projection = (normalised_data ...
                          - repmat(mean(normalised_data), no_lines, 1)) ...
                                                * pc(:,1:target_dimension);
     
end