function probabilities = S3_kernel_smoothing(points_to_evaluate, weight_points, bandwidth_factor, independent_axes, handles)
    % probabilities = S3_kernel_smoothing(points_to_evaluate, weight_points, bandwidth_factor, independent_axes)
    % 
    %  input:
    %           points_to_evaluate = Points to determine probability for
    %           weight_points      = Points to apply kernel function on
    %           bandwidth_factor   = Scaling factor for bandwidth of the 
    %                                Gaussian kernel
    %           independent_axes   = If true, kernel adapted according to SD
    %                                on each axis independently.
    % output:
    %           probabilities      = Estimated probabilities
    %
    % "Beyond the Average"-workflow -- Step 3
    % Assign probabilities to all nodes.
    
    % Christoph Echtermeyer, 2009-2010
    
    if independent_axes
        bandwidth1 = bandwidth_factor * std(weight_points(:,1));
        bandwidth2 = bandwidth_factor * std(weight_points(:,2));
    else
        s = mean( std(weight_points) );
        bandwidth1 = bandwidth_factor * s;
        bandwidth2 = bandwidth1;
    end
    
    handles.dummy = 0; % to make sure "handles" is defined if not passed as arg
    
    if(octave_running())
       
        % use equivalent to matlab 'ksdensity' function (from pkg econometrics)
        p1 = kernel_density(points_to_evaluate(:,1), weight_points(:,1), bandwidth1, '__kernel_normal');
        p2 = kernel_density(points_to_evaluate(:,2), weight_points(:,2), bandwidth2, '__kernel_normal');

    else % assume it's matlab

        if isfield(handles, 'pdf_weights') > 0
            p1 = ksdensity(weight_points(:,1), points_to_evaluate(:,1), ...
                'kernel', 'normpdf', 'width', bandwidth1, 'function', 'pdf', ...
                'weights', handles.pdf_weights);
            
            p2 = ksdensity(weight_points(:,2), points_to_evaluate(:,2), ...
                'kernel', 'normpdf', 'width', bandwidth2, 'function', 'pdf', ...
                'weights', handles.pdf_weights);
        else
            p1 = ksdensity(weight_points(:,1), points_to_evaluate(:,1), ...
                'kernel', 'normpdf', 'width', bandwidth1, 'function', 'pdf');
            
            p2 = ksdensity(weight_points(:,2), points_to_evaluate(:,2), ...
                'kernel', 'normpdf', 'width', bandwidth2, 'function', 'pdf');
        end
    end
    
    probabilities = p1 .* p2;

end
