function [k_auto, centroids, noOfpointsInCluster, assignments] = S5f_fast_group_nodes(points_to_cluster) 
    % [k_auto, centroids, noOfpointsInCluster, assignments] = S5f_fast_group_nodes(points_to_cluster) 
    % 
    %  input:
    %           points_to_cluster   = Data points to cluster
    % output:
    %           k_auto              = Identified number of clusters
    %           centroids           = dummy output for compatibility
    %           noOfpointsInCluster = Number of points assigned to cluster
    %           assignments         = IDs of clusters nodes have been assigned to
    %
    % "Beyond the Average"-workflow -- Step 5
    % Helper function to determine motif groups according to overlap-grouping 
    % described in paper. 
    
    % Christoph Feenders (ne Echtermeyer), 2009-2013
     
    no_of_points   = size(points_to_cluster, 1);
    overlap_matrix = eye(no_of_points);
    for i = 1:no_of_points
        for j = (i+1):no_of_points
            i_and_j_overlapping = distance(points_to_cluster(i, :), ...
                                                points_to_cluster(j, :)) < 1;
            overlap_matrix(i,j) = i_and_j_overlapping;
            overlap_matrix(j,i) = i_and_j_overlapping;
        end
    end
    
    shortest_path_matrix = get_shortest_path_matrix(overlap_matrix, no_of_points-1); 
    assignments = zeros(no_of_points, 1);
    next_colour = 1;
    for i = 1:no_of_points
        if assignments(i) > 0
            current_colour = assignments(i);
        else
            current_colour = next_colour;
            next_colour = next_colour + 1;
        end
        for j = 1:no_of_points
            if shortest_path_matrix(i,j) > 0
                assignments(j) = current_colour;
            end
        end
    end
    k_auto = next_colour - 1;

    noOfpointsInCluster = zeros(k_auto, 1);
    for i = 1:k_auto
        noOfpointsInCluster(i) = sum( assignments==i );
    end

    centroids = zeros(k_auto, size(points_to_cluster, 2)); % fake assigment

end


% using sub-function rather than private/nested function for octave-compatibility
function dist = distance(p1, p2)
   
    dist = sqrt( (p1(1) - p2(1))^2 + (p1(2) - p2(2))^2 );

end
