function workflow_fingerprint(handles)
    % workflow_fingerprint(handles) 
    % 
    %  input:
    %           handles = Handle structure of BtA-GUI
    % output:
    %           (none)
    %
    % "Beyond the Average"-workflow -- Step 9
    % Calculate relative frequencies for motif regions.
    
    % Christoph Echtermeyer, 2009-2010
  
    statistics          = handles.statistics;
    stats_description   = handles.stats_description;
    probabilities       = handles.probabilities;
    singular_nodes      = handles.singular_nodes;
    regular_nodes       = handles.regular_nodes;
    noOfpointsInCluster = handles.noOfpointsInCluster;
    file_basename       = handles.file_basename;
    no_of_nodes         = handles.no_of_nodes;
    assignments         = handles.assignments;
    k                   = handles.k;
    w                   = handles.w;
    no_of_regular_nodes = no_of_nodes - w;


    % characterise motifs
    [sorted, i] = sort(probabilities);
    regular_stats_mean = mean( statistics( i(w+1:no_of_nodes), : ), 1);
    regular_stats_sdev = std( statistics( i(w+1:no_of_nodes), : ), 1);
    print_stats('MEAN', 0, no_of_nodes-w, regular_stats_mean);
    print_stats('SDEV', 0, no_of_nodes-w, regular_stats_sdev);

    descriptions = cell(1, k);
    for a = 1:k

        points_in_cluster_a_idx = find(assignments == a);
        cluster_stats           = statistics(i(points_in_cluster_a_idx), :);
        cluster_stats_mean      = mean(cluster_stats, 1);
        if noOfpointsInCluster(a) == 1
            cluster_stats_sdev = zeros(size(cluster_stats_mean));
        else
            cluster_stats_sdev = std(cluster_stats, 1);
        end
        print_stats('MEAN', a, noOfpointsInCluster(a), cluster_stats_mean);
        print_stats('SDEV', a, noOfpointsInCluster(a), cluster_stats_sdev);

        large = cluster_stats_mean - cluster_stats_sdev > regular_stats_mean + regular_stats_sdev;
        small = cluster_stats_mean + cluster_stats_sdev < regular_stats_mean - regular_stats_sdev;
        medium = ((cluster_stats_mean + cluster_stats_sdev <= regular_stats_mean + regular_stats_sdev) ...
                & (cluster_stats_mean - cluster_stats_sdev >= regular_stats_mean - regular_stats_sdev));

        print_stats('SMALL', a, noOfpointsInCluster(a), small);
        print_stats('MEDIUM', a, noOfpointsInCluster(a), medium);
        print_stats('LARGE', a, noOfpointsInCluster(a), large);

        description = sprintf('cluster %i ', a);
        text_to_add = '';
        for l = 1:size(small,2)
            if( small(l) == 1 )
                text_to_add = sprintf('%s %s', text_to_add, char(stats_description(l)));
            end
        end
        if( text_to_add ) 
            description = sprintf('%s\n %s %s', description, 'small', text_to_add);
        end

        text_to_add = '';
        for l = 1:size(medium,2)
            if( medium(l) == 1 )
                text_to_add = sprintf('%s %s', text_to_add, char(stats_description(l)));
            end
        end
        if( text_to_add ) 
            description = sprintf('%s\n %s %s', description, 'medium', text_to_add);
        end
        
        text_to_add = '';
        for l = 1:size(large,2)
            if( large(l) == 1 )
                text_to_add = sprintf('%s %s', text_to_add, char(stats_description(l)));
            end
        end
        if( text_to_add ) 
            description = sprintf('%s\n %s %s', description, 'large', text_to_add);
        end
            
        descriptions(a) = cellstr(description);
    
    end

    axes(handles.axes5);
    relative_frequencies = [noOfpointsInCluster.' / no_of_nodes, no_of_regular_nodes / no_of_nodes];
    bar(relative_frequencies);
    xlabel('motif');
    ylabel('relative frequency');
    title('network fingerprint');
    axis('tight');
    
    y = 0.8 * no_of_regular_nodes / no_of_nodes;
    y_step = (no_of_regular_nodes / no_of_nodes) / (k + 3);
    txt = char(descriptions);
    for a = 1:k
        text(a-0.35, y, txt(a,:))
        y = y - y_step;
        fprintf('%s\n', txt(a,:));
    end
end

function print_stats(description, ID, cluster_size, values_to_print)
% comment out to have cluster characterisation printed to console
%    fprintf('%s cluster %i (size %i): ', description, ID, cluster_size);
%    fprintf('%.2f ', values_to_print);
%    fprintf('\n');
end
