function varargout = sinomo(varargin)
% sinomo()
% 
%  input:
%           (none)
% output:
%           (none) 
%
% Graphical user interface to control "Beyond the Average"-workflow.
% [Notes: sinomo.fig file required to run; only one instance of the function
%         can be run at any time (singleton).]
%
% When called a file-selection dialog allows to chose the file to analyse.
% After initialisation different plots and parameter controls allow to 
% alter the default settings that were determined.
%
% Christoph Echtermeyer, 2009-2010

% Edit the above text to modify the response to help sinomo

% Last Modified by GUIDE v2.5 03-Nov-2011 16:25:57

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @sinomo_OpeningFcn, ...
                   'gui_OutputFcn',  @sinomo_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

% --- Executes just before sinomo is made visible.
function sinomo_OpeningFcn(hObject, eventdata, handles, varargin)
    % This function has no output args, see OutputFcn.
    % hObject    handle to figure
    % eventdata  reserved - to be defined in a future version of MATLAB
    % handles    structure with handles and user data (see GUIDATA)
    % varargin   command line arguments to sinomo (see VARARGIN)

        % not using matlab-package structure to ensure octave-compatibility
        % adding paths instead
        base_dir = pwd;
        addpath( sprintf('%s/%s', base_dir, '!workflow') );
        addpath( sprintf('%s/%s', base_dir, '!graphStats') );
        addpath( sprintf('%s/%s', base_dir, '!dataHandling') );

%    I = imread('logo.jpg');
%    uiwait(msgbox('String','Title','custom',I), 1);
    
    % show file-selection dialog
    [FileName,PathName] = uigetfile('*.csv','Select connectivity-file');
    filename = [PathName FileName];
    if( filename == 0 )
        quit;   % exit if file-selection cancelled
    end
    initial_waitbar = waitbar(0.02,'Calculating network statistics. Please wait...');

    % set name for output
    r = strfind(filename, '.csv');
    handles.file_basename = filename(1 : r(end)-1);

    % read in adjacency matrix
    [handles.connectivity_matrix, dimension] = get_matrix_from_csv_file(filename);

    % get local statistics
%    [handles.statistics, handles.stats_description] = S1_calculate_stats(handles.connectivity_matrix);
    [handles.statistics, handles.stats_description] = S1_calculate_stats(handles.connectivity_matrix, handles);

    % perform principal comonent analysis
    pcs = 2; % number of principal components
    [handles.eigenspace_projection, handles.explained_variance] = S2_PCA(handles.statistics, pcs);
    waitbar(0.70);

    [handles.t_x, handles.t_y, handles.grid_points] = S0h_get_grid_points(handles);
    waitbar(0.85);

    % make sure essential variables are initialised
    handles.no_of_nodes = size(handles.connectivity_matrix, 1);

    handles.bandwidth_min = 0.1;
    handles.bandwidth_max = 1.0;
    handles.bandwidth = 1;
    handles.bandwidth_old = handles.bandwidth;
    handles.bandwidth_changed = true;
    handles.adapt_kernel = true;

    handles.w_min = 1;
    handles.w_max = floor(handles.no_of_nodes/2);
    handles.w = floor(handles.w_max * 0.1);
    handles.w = max(handles.w_min, handles.w);
    handles.w_old = handles.w;
    handles.w_changed = true;

    handles.k_min = 1;
    handles.k_max = handles.w;
    handles.k = handles.k_min; % max(handles.k_min, round(0.3 * handles.w));
    handles.k_old = handles.k;
    handles.k_changed = true;

    handles.automatic_saving = 0;
    handles.automatic_plot_update = 1;
    handles.motif_grouping_function = 'overlap';

    % Choose default command line output for sinomo
    handles.output = hObject;

    % set GUI variable controls according to settings above
    handles = update_GUI_variable_controls(handles);
    waitbar(0.99);
    delete(initial_waitbar);

    % generate all plots (for the first time)
    handles = update_my_graphics(handles);

    % Update handles structure
    guidata(hObject, handles);


function handles = update_my_graphics(handles, manual_update)
    % Update plots related to "Beyond the Average"-workflow.
    % Computations preceeding plots are performed only if relevant parameters
    % have changed, such that results may be affected; otherwise redundant
    % evaluations are skipped.
    
    % update plots only if requested to do so either automatically 
    % (auto_plot_update) or explicitely (second input argument present).
    if( handles.automatic_plot_update == 1 || nargin == 2 )
    
        % updates required if bandwidth has changed
        a_waitbar =  waitbar(0.01,'Updating plots. Please wait...');
        if( handles.bandwidth_changed )
            % estimate probabilites for all nodes
            handles.probabilities = S3_kernel_smoothing(handles.eigenspace_projection, ...
                handles.eigenspace_projection, handles.bandwidth, handles.adapt_kernel);

            waitbar(0.15);

            % plot preparation
            density = S3_kernel_smoothing(handles.grid_points, ...
                handles.eigenspace_projection, handles.bandwidth, handles.adapt_kernel);
            handles.density_matrix = reshape(density, 100, 100);
            
            % select new w
            handles.w = S4_determine_w(handles.probabilities);
            handles.k_max = handles.w;                
        end
        waitbar(0.35);

        % updates required if bandwidth or w has changed
        if( handles.bandwidth_changed || handles.w_changed )
            % set singular_nodes according to iterator variable w
            [unused_dummy, handles.sorted_index] = sort(handles.probabilities);
            handles.singular_nodes = handles.eigenspace_projection( handles.sorted_index(1:handles.w), : );
            handles.regular_nodes  = handles.eigenspace_projection( handles.sorted_index(handles.w+1:handles.no_of_nodes), : );
    
            % select new k
            handles.k = S5f_determine_k(handles);
        end
        waitbar(0.40);

        % updates required if bandwidth, w, or k has changed
        if( handles.bandwidth_changed || handles.w_changed || handles.k_changed )
            % group singular nodes
            SD = std(handles.eigenspace_projection);
            normalised_points = handles.singular_nodes ./ (ones(size(handles.singular_nodes,1), 1) * SD);
            % constant rows have SD=0, so normalised data contains NaNs; replace
            % them with zeros
            normalised_points(isnan(normalised_points)) = 0;

            switch handles.motif_grouping_function
                case 'kmeans'
                    [handles.centroids, handles.noOfpointsInCluster, handles.assignments] = S5b_group_nodes(normalised_points, handles.k);
                case 'overlap'
                    [dummy_k, handles.centroids, handles.noOfpointsInCluster, handles.assignments] = S5f_fast_group_nodes(normalised_points);
                otherwise
                    error('Unknown clustering method selected.')
            end
        
            outlierID_clusterID = [handles.sorted_index(1:handles.w), handles.assignments]
            
            handles = update_GUI_variable_controls(handles);
            handles.bandwidth_changed = false;
            handles.w_changed = false;
            handles.k_changed = false;
        end
        waitbar(0.55);
 
        % workflow-computations finished; update actual plots
        workflow_plots(handles);
        waitbar(0.75);

        % make network fingerprint
        workflow_fingerprint(handles)
        waitbar(0.99);
        delete(a_waitbar);
        
        % if automatic saving enabled store plots to file
        if( handles.automatic_saving == 1 )
            save_plot(handles);
        end
    end

    
function save_plot(handles)
    
    a_waitbar =  waitbar(0.01,'Saving plots. Please wait...');

    % save plots as PDF
    image_filename = sprintf('%s_bw_%.2f_w_%i_k_%i.pdf', ...
        handles.file_basename, handles.bandwidth, handles.w, handles.k);
        
    
    axes_to_save = [handles.axes1, handles.axes2, handles.axes3, handles.axes4, handles.axes5];
    no_of_axes_to_save = length(axes_to_save);
    
    %create a new figure
    newFig = figure('Visible','off');
    set(newFig,'PaperUnits','centimeters');
    set(gcf, 'PaperSize', [30 20]);
%    set(newFig,'PaperPositionMode','auto');
    set(gcf, 'PaperPositionMode', 'manual');
    set(gcf, 'PaperPosition', [0 0 30 20]);
    
    j = 1;
    for i = 1:no_of_axes_to_save
        if( i > 2 )
            j = i + 1;
        else
            j = i;
        end
        h = subplot(2,3,j); 
        a = get(axes_to_save(i), 'Children'); 
        copyobj(a, h); 
        axis('tight');
        waitbar(i/(1+no_of_axes_to_save));
    end
    %saves the plot
%    saveas(newFig,image_filename) 
    print(newFig, '-dpdf', image_filename);
    
    %closes the figure
    close(newFig)
    waitbar(0.99);
    delete(a_waitbar);
 

function save_analysis_results_to_mat_file(handles)

    % save statistics
    a_waitbar =  waitbar(0.02,'Saving plots. Please wait...');
    save_analysis_results(handles);
    waitbar(0.99);
    delete(a_waitbar);


function handles = update_GUI_variable_controls(handles)

    % Update bandwidth controls
    handles.bandwidth_changed = handles.bandwidth_changed || ( handles.bandwidth ~= handles.bandwidth_old );
    if( handles.bandwidth_changed )
        bandwidth_percental = (handles.bandwidth - handles.bandwidth_min) / (handles.bandwidth_max - handles.bandwidth_min);
        set(handles.bandwidth_slider, 'Value', bandwidth_percental);
        set(handles.BW_edit, 'String', num2str(handles.bandwidth, 2));
        handles.bandwidth_old = handles.bandwidth;
    end
        
    % Update w controls
    handles.w_changed = handles.w_changed || ( handles.w ~= handles.w_old );
    if( handles.w_changed ) 
        w_percental = (handles.w - handles.w_min) / (handles.w_max - handles.w_min);
        set(handles.w_slider, 'Value', w_percental);
        set(handles.w_edit, 'String', int2str(handles.w));
        handles.w_old = handles.w;
    end
        
    % Update k controls
    handles.k_changed = handles.k_changed || ( handles.k ~= handles.k_old );
    if( handles.k_changed )
        k_percental = (handles.k - handles.k_min) / (handles.k_max - handles.k_min);
        set(handles.k_slider, 'Value', k_percental);
        set(handles.k_edit, 'String', num2str(handles.k));
        handles.k_old = handles.k;
    end
    

% --- Outputs from this function are returned to the command line.
function varargout = sinomo_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes on slider movement.
function w_slider_Callback(hObject, eventdata, handles)
% hObject    handle to w_slider (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider

old_w = handles.w;
percentage = get(hObject,'Value');
handles.w = round( handles.w_min + percentage * (handles.w_max - handles.w_min) );
if( handles.w ~= old_w )
    handles.k_max = handles.w;
    handles.k = min( handles.k, handles.k_max );
    handles = update_GUI_variable_controls(handles);
    handles = update_my_graphics(handles);
    % Update handles structure
    guidata(hObject, handles);
end

% --- Executes during object creation, after setting all properties.
function w_slider_CreateFcn(hObject, eventdata, handles)
% hObject    handle to w_slider (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes on slider movement.
function k_slider_Callback(hObject, eventdata, handles)
% hObject    handle to k_slider (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider

old_k = handles.k;
percentage = get(hObject,'Value');
handles.k = round( handles.k_min + percentage * (handles.k_max - handles.k_min) );
if( handles.k ~= old_k )
    handles = update_GUI_variable_controls(handles);
    handles = update_my_graphics(handles);
    % Update handles structure
    guidata(hObject, handles);
end


% --- Executes during object creation, after setting all properties.
function k_slider_CreateFcn(hObject, eventdata, handles)
% hObject    handle to k_slider (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes on slider movement.
function bandwidth_slider_Callback(hObject, eventdata, handles)
% hObject    handle to bandwidth_slider (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'Value') returns position of slider
%        get(hObject,'Min') and get(hObject,'Max') to determine range of slider

old_bandwidth = handles.bandwidth;
percentage = get(hObject,'Value');
handles.bandwidth = handles.bandwidth_min + ...
    percentage * (handles.bandwidth_max - handles.bandwidth_min);
if( handles.bandwidth ~= old_bandwidth )
    handles = update_GUI_variable_controls(handles);
    handles = update_my_graphics(handles);
    % Update handles structure
    guidata(hObject, handles);
end


% --- Executes during object creation, after setting all properties.
function bandwidth_slider_CreateFcn(hObject, eventdata, handles)
% hObject    handle to bandwidth_slider (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: slider controls usually have a light gray background.
if isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor',[.9 .9 .9]);
end


% --- Executes on button press in save_button.
function save_button_Callback(hObject, eventdata, handles)
% hObject    handle to save_button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
if( handles.automatic_plot_update == 0 )
    handles = update_my_graphics(handles, 1);
    % Update handles structure
    guidata(hObject, handles);
end
save_plot(handles);


% --- Executes on button press in autosave_checkbox.
function autosave_checkbox_Callback(hObject, eventdata, handles)
% hObject    handle to autosave_checkbox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of autosave_checkbox
handles.automatic_saving = round(get(hObject,'Value'));
if( handles.automatic_saving == 1 )
    save_plot(handles);
    set(handles.save_button, 'Enable', 'off');
else
    set(handles.save_button, 'Enable', 'on');
end
% Update handles structure
guidata(hObject, handles);


% --- Executes on button press in plotupdate_button.
function plotupdate_button_Callback(hObject, eventdata, handles)
% hObject    handle to plotupdate_button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
handles = update_my_graphics(handles, 1);
% Update handles structure
guidata(hObject, handles);


% --- Executes on button press in wpp_button.
function wpp_button_Callback(hObject, eventdata, handles)
% hObject    handle to wpp_button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
old_w = handles.w;
handles.w = min( handles.w + 1, handles.w_max );
if( handles.w ~= old_w )
    handles.k_max = handles.w;
    handles.k = min( handles.k, handles.k_max );
    handles = update_GUI_variable_controls(handles);
    handles = update_my_graphics(handles);
    % Update handles structure
    guidata(hObject, handles);
end 


% --- Executes on button press in wmm_button.
function wmm_button_Callback(hObject, eventdata, handles)
% hObject    handle to wmm_button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
old_w = handles.w;
handles.w = max( handles.w - 1, handles.w_min );
if( handles.w ~= old_w )
    handles.k_max = handles.w;
    handles.k = min( handles.k, handles.k_max );
    handles = update_GUI_variable_controls(handles);
    handles = update_my_graphics(handles);
    % Update handles structure
    guidata(hObject, handles);
end 


% --- Executes on button press in kpp_button.
function kpp_button_Callback(hObject, eventdata, handles)
% hObject    handle to kpp_button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
old_k = handles.k;
handles.k = min( handles.k + 1, handles.k_max );
if( handles.k ~= old_k )
    handles = update_GUI_variable_controls(handles);
    handles = update_my_graphics(handles);
    % Update handles structure
    guidata(hObject, handles);
end 



% --- Executes on button press in kmm_button.
function kmm_button_Callback(hObject, eventdata, handles)
% hObject    handle to kmm_button (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
old_k = handles.k;
handles.k = max( handles.k - 1, handles.k_min );
if( handles.k ~= old_k )
    handles = update_GUI_variable_controls(handles);
    handles = update_my_graphics(handles);
    % Update handles structure
    guidata(hObject, handles);
end 


function BW_edit_Callback(hObject, eventdata, handles)
% hObject    handle to BW_edit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of BW_edit as text
%        str2double(get(hObject,'String')) returns contents of BW_edit as a double
entered_bandwidth = str2double(get(hObject,'String'));

old_bandwidth = handles.bandwidth;
if( entered_bandwidth > handles.bandwidth_max )
    handles.bandwidth = handles.bandwidth_max;
elseif( entered_bandwidth < handles.bandwidth_min )
    handles.bandwidth = handles.bandwidth_min;
else
    handles.bandwidth = entered_bandwidth;
end

if( handles.bandwidth ~= old_bandwidth ) 
    handles = update_GUI_variable_controls(handles);
    handles = update_my_graphics(handles);
    % Update handles structure
    guidata(hObject, handles);
end   


% --- Executes during object creation, after setting all properties.
function BW_edit_CreateFcn(hObject, eventdata, handles)
% hObject    handle to BW_edit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function w_edit_Callback(hObject, eventdata, handles)
% hObject    handle to w_edit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of w_edit as text
%        str2double(get(hObject,'String')) returns contents of w_edit as a double
entered_w = round( str2double(get(hObject,'String')) );

old_w = handles.w;
if( entered_w > handles.w_max )
    handles.w = handles.w_max;
elseif( entered_w < handles.w_min )
    handles.w = handles.w_min;
else
    handles.w = entered_w;
end

if( handles.w ~= old_w ) 
    handles = update_GUI_variable_controls(handles);
    handles = update_my_graphics(handles);
    % Update handles structure
    guidata(hObject, handles);
end   


% --- Executes during object creation, after setting all properties.
function w_edit_CreateFcn(hObject, eventdata, handles)
% hObject    handle to w_edit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


function k_edit_Callback(hObject, eventdata, handles)
% hObject    handle to k_edit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: get(hObject,'String') returns contents of k_edit as text
%        str2double(get(hObject,'String')) returns contents of k_edit as a double
entered_k = round( str2double(get(hObject,'String')) );

old_k = handles.k;
if( entered_k > handles.k_max )
    handles.k = handles.k_max;
elseif( entered_k < handles.k_min )
    handles.k = handles.k_min;
else
    handles.k = entered_k;
end

if( handles.k ~= old_k ) 
    handles = update_GUI_variable_controls(handles);
    handles = update_my_graphics(handles);
    % Update handles structure
    guidata(hObject, handles);
end   

% --- Executes during object creation, after setting all properties.
function k_edit_CreateFcn(hObject, eventdata, handles)
% hObject    handle to k_edit (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: edit controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes on button press in auto_plot_update_box.
function auto_plot_update_box_Callback(hObject, eventdata, handles)
% hObject    handle to auto_plot_update_box (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of auto_plot_update_box
handles.automatic_plot_update = round(get(hObject,'Value'));
if( handles.automatic_plot_update == 1 )
    set(handles.autosave_checkbox, 'Enable', 'on');
    set(handles.plotupdate_button, 'Enable', 'off');
    handles = update_my_graphics(handles);
else
    set(handles.autosave_checkbox, 'Enable', 'off');
    set(handles.plotupdate_button, 'Enable', 'on');
end
% Update handles structure
guidata(hObject, handles);


% --- Executes when selected object is changed in sing_node_selection.
function sing_node_selection_SelectionChangeFcn(hObject, eventdata, handles)
% hObject    handle to the selected object in sing_node_selection 
% eventdata  structure with the following fields (see UIBUTTONGROUP)
%	EventName: string 'SelectionChanged' (read only)
%	OldValue: handle of the previously selected object or empty if none was selected
%	NewValue: handle of the currently selected object
% handles    structure with handles and user data (see GUIDATA)

switch get(eventdata.NewValue,'Tag')   % Get Tag of selected object
    case 'predef_radiobutton'
      
        
    case 'custom_radiobutton'
%        manual_selection('points', handles.eigenspace_projection);
%        manual_selection('the_axes', sprintf('%i', handles.axes3) );

    case 'dummy custom_radiobutton'
        clipboard('copy', '')
        newFig = figure;
        newaxes = axes;
        a = get(handles.axes3, 'Children'); 
        copyobj(a, newaxes);
        brush(newFig, 'on');
        waitfor(newFig, 'BeingDeleted', 'On');
%        uiwait(newFig);
        str = clipboard('paste');
        if( length(str) > 0 )
            char(str)
        end
end


% --- Executes when user attempts to close main_window.
function main_window_CloseRequestFcn(hObject, eventdata, handles)
% hObject    handle to main_window (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: delete(hObject) closes the figure
delete(hObject);


% --- Executes during object creation, after setting all properties.
function sing_node_selection_CreateFcn(hObject, eventdata, handles)
% hObject    handle to sing_node_selection (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called


% --- Executes on button press in save_mat_pushbutton.
function save_mat_pushbutton_Callback(hObject, eventdata, handles)
% hObject    handle to save_mat_pushbutton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
save_analysis_results_to_mat_file(handles);


% --- Executes on button press in adapt_kernel_checkbox.
function adapt_kernel_checkbox_Callback(hObject, eventdata, handles)
% hObject    handle to adapt_kernel_checkbox (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of adapt_kernel_checkbox
handles.adapt_kernel = round(get(hObject,'Value'));
handles.bandwidth_changed = true;
handles = update_my_graphics(handles);
% Update handles structure
guidata(hObject, handles);


% --- Executes when selected object is changed in motif_grouping_selection.
function motif_grouping_selection_SelectionChangeFcn(hObject, eventdata, handles)
% hObject    handle to the selected object in motif_grouping_selection 
% eventdata  structure with the following fields (see UIBUTTONGROUP)
%	EventName: string 'SelectionChanged' (read only)
%	OldValue: handle of the previously selected object or empty if none was selected
%	NewValue: handle of the currently selected object
% handles    struswitch get(eventdata.NewValue,'Tag')   % Get Tag of selected object
switch get(eventdata.NewValue,'Tag')   % Get Tag of selected object
    case 'overlap_radiobutton'
        handles.motif_grouping_function = 'overlap';
        set(handles.k_edit    , 'Enable', 'off');
        set(handles.k_slider  , 'Enable', 'off');
        set(handles.kpp_button, 'Enable', 'off');
        set(handles.kmm_button, 'Enable', 'off');
    case 'kmeans_radiobutton'
        handles.motif_grouping_function = 'kmeans';
        set(handles.k_edit    , 'Enable', 'on');
        set(handles.k_slider  , 'Enable', 'on');
        set(handles.kpp_button, 'Enable', 'on');
        set(handles.kmm_button, 'Enable', 'on');
end
handles.k = S5f_determine_k(handles);
handles.k_changed = true;
handles = update_GUI_variable_controls(handles);
handles = update_my_graphics(handles);
% Update handles structure
guidata(hObject, handles);


% --------------------------------------------------------------------
function motif_grouping_selection_ButtonDownFcn(hObject, eventdata, handles)
% hObject    handle to motif_grouping_selection (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
